==> profile-changer-widget_0.8-3.tar.gz: profile-changer-widget-0.8/src/settingsdialog.cpp <==
#include "settingsdialog.h"
#include "ui_settingsdialog.h"
#include <QLibraryInfo>

SettingsDialog::SettingsDialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::SettingsDialog)
{
    ui->setupUi(this);
    setAttribute(Qt::WA_DeleteOnClose);
    QSettings settings;
    ui->heightBox->setValue(settings.value("profilechangerwidget/height").toInt());
    ui->widthBox->setValue(settings.value("profilechangerwidget/width").toInt());
    QPushButton *aboutButton = new QPushButton(tr("About"), this);
    connect(aboutButton, SIGNAL(clicked()), this, SLOT(showAbout()));
    connect(this, SIGNAL(rejected()), this, SLOT(close()));
    ui->buttonBox->addButton(aboutButton, QDialogButtonBox::NoRole);
}

SettingsDialog::~SettingsDialog()
{
    delete ui;
}

void SettingsDialog::accept()
{
    QSettings settings;
    if (ui->heightBox->text().isEmpty() || ui->widthBox->text().isEmpty()) {
        QMaemo5InformationBox::information(this, tr("Fields cannot be empty!"));
        return;
    }
    settings.setValue("profilechangerwidget/width", ui->widthBox->value());
    settings.setValue("profilechangerwidget/height", ui->heightBox->value());
    emit settingsChanged();
    this->close();
}

void SettingsDialog::showAbout()
{
    QMaemo5InformationBox::information(this, QLibraryInfo::location(QLibraryInfo::TranslationsPath));
    QDialog *aboutDialog = new QDialog(0);
    aboutDialog->setAttribute(Qt::WA_DeleteOnClose);
    aboutDialog->setWindowTitle(tr("About Profile Changer Widget"));
    QLabel *aboutText = new QLabel(aboutDialog);
    QString about;
    about.append(tr("Profile Changer Widget"));
    about.append("\n");
    about.append(tr("Small widget intended to enable an easy change between general and silent profiles."));
    about.append("\n\n");
    about.append(tr("Version:"));
    about.append(" ");
    about.append(QApplication::applicationVersion());
    about.append(", ");
    about.append(QString::fromUtf8("© 2012 Harald Schmitt\n"));
    aboutText->setText(about);
    aboutText->setWordWrap(true);
    QScrollArea *aboutScroll = new QScrollArea(aboutDialog);
    QVBoxLayout *scrollLayout = new QVBoxLayout(aboutScroll);
    scrollLayout->addWidget(aboutText);
    QVBoxLayout *layout = new QVBoxLayout(aboutDialog);
    layout->addWidget(aboutScroll);
    aboutDialog->setLayout(layout);
    aboutDialog->show();
    this->close();
}

==> profile-changer-widget_0.8-5.tar.gz: profile-changer-widget-0.8/src/settingsdialog.cpp <==
#include "settingsdialog.h"
#include "ui_settingsdialog.h"
#include <QLibraryInfo>

SettingsDialog::SettingsDialog(QWidget *parent) :
    QDialog(parent),
    ui(new Ui::SettingsDialog)
{
    ui->setupUi(this);
    setAttribute(Qt::WA_DeleteOnClose);
    QSettings settings;
    ui->heightBox->setValue(settings.value("profilechangerwidget/height").toInt());
    ui->widthBox->setValue(settings.value("profilechangerwidget/width").toInt());
    QPushButton *aboutButton = new QPushButton(tr("About"), this);
    connect(aboutButton, SIGNAL(clicked()), this, SLOT(showAbout()));
    connect(this, SIGNAL(rejected()), this, SLOT(close()));
    ui->buttonBox->addButton(aboutButton, QDialogButtonBox::NoRole);
}

SettingsDialog::~SettingsDialog()
{
    delete ui;
}

void SettingsDialog::accept()
{
    QSettings settings;
    if (ui->heightBox->text().isEmpty() || ui->widthBox->text().isEmpty()) {
        QMaemo5InformationBox::information(this, tr("Fields cannot be empty!"));
        return;
    }
    if (ui->heightBox->text() == "99") {
        QMaemo5InformationBox::information(this, "TranslationPath: " + QLibraryInfo::location(QLibraryInfo::TranslationsPath));
        return;
    }


    settings.setValue("profilechangerwidget/width", ui->widthBox->value());
    settings.setValue("profilechangerwidget/height", ui->heightBox->value());
    emit settingsChanged();
    this->close();
}

void SettingsDialog::showAbout()
{
    QDialog *aboutDialog = new QDialog(0);
    aboutDialog->setAttribute(Qt::WA_DeleteOnClose);
    aboutDialog->setWindowTitle(tr("About Profile Changer Widget"));
    QLabel *aboutText = new QLabel(aboutDialog);
    QString about;
    about.append(tr("Profile Changer Widget"));
    about.append("\n");
    about.append(tr("Small widget intended to enable an easy change between general and silent profiles."));
    about.append("\n\n");
    about.append(tr("Version:"));
    about.append(" ");
    about.append(QApplication::applicationVersion());
    about.append(", ");
    about.append(QString::fromUtf8("© 2012 Harald Schmitt\n"));
    aboutText->setText(about);
    aboutText->setWordWrap(true);
    QScrollArea *aboutScroll = new QScrollArea(aboutDialog);
    QVBoxLayout *scrollLayout = new QVBoxLayout(aboutScroll);
    scrollLayout->addWidget(aboutText);
    QVBoxLayout *layout = new QVBoxLayout(aboutDialog);
    layout->addWidget(aboutScroll);
    aboutDialog->setLayout(layout);
    aboutDialog->show();
    this->close();
}
